==> paraview_5.9.0.orig.tar.xz: paraview-5.9.0/Qt/Core/pqScalarBarRepresentation.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqScalarBarRepresentation.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqScalarBarRepresentation.h"

#include "pqUndoStack.h"
#include "vtkCommand.h"
#include "vtkEventQtSlotConnect.h"
#include "vtkSMPropertyModificationUndoElement.h"
#include "vtkSMProxy.h"

//-----------------------------------------------------------------------------
pqScalarBarRepresentation::pqScalarBarRepresentation(const QString& group, const QString& name,
  vtkSMProxy* scalarbar, pqServer* server, QObject* _parent)
  : Superclass(group, name, scalarbar, server, _parent)
{
  vtkEventQtSlotConnect* connector = this->getConnector();

  // Listen to start/end interactions to update the application undo-redo stack
  // correctly.
  connector->Connect(scalarbar, vtkCommand::StartInteractionEvent, this, SLOT(startInteraction()));
  connector->Connect(scalarbar, vtkCommand::EndInteractionEvent, this, SLOT(endInteraction()));
}

//-----------------------------------------------------------------------------
pqScalarBarRepresentation::~pqScalarBarRepresentation()
{
}

//-----------------------------------------------------------------------------
#define PUSH_PROPERTY(name)                                                                        \
  {                                                                                                \
    vtkSMPropertyModificationUndoElement* elem = vtkSMPropertyModificationUndoElement::New();      \
    elem->ModifiedProperty(proxy, name);                                                           \
    ADD_UNDO_ELEM(elem);                                                                           \
    elem->Delete();                                                                                \
  }

//-----------------------------------------------------------------------------
void pqScalarBarRepresentation::startInteraction()
{
  BEGIN_UNDO_SET("Move Color Legend");

  vtkSMProxy* proxy = this->getProxy();
  PUSH_PROPERTY("Position");
  PUSH_PROPERTY("ScalarBarLength");
  PUSH_PROPERTY("Orientation");
}

//-----------------------------------------------------------------------------
void pqScalarBarRepresentation::endInteraction()
{
  vtkSMProxy* proxy = this->getProxy();
  PUSH_PROPERTY("Orientation");
  PUSH_PROPERTY("ScalarBarLength");
  PUSH_PROPERTY("Position");
  END_UNDO_SET();
}

==> paraview_5.10.0~rc1.orig.tar.xz: paraview-5.10.0~rc1/Qt/Core/pqScalarBarRepresentation.cxx <==
/*=========================================================================

   Program: ParaView
   Module:    pqScalarBarRepresentation.cxx

   Copyright (c) 2005-2008 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/
#include "pqScalarBarRepresentation.h"

#include "pqUndoStack.h"
#include "vtkCommand.h"
#include "vtkEventQtSlotConnect.h"
#include "vtkSMPropertyModificationUndoElement.h"
#include "vtkSMProxy.h"

//-----------------------------------------------------------------------------
pqScalarBarRepresentation::pqScalarBarRepresentation(const QString& group, const QString& name,
  vtkSMProxy* scalarbar, pqServer* server, QObject* _parent)
  : Superclass(group, name, scalarbar, server, _parent)
{
  vtkEventQtSlotConnect* connector = this->getConnector();

  // Listen to start/end interactions to update the application undo-redo stack
  // correctly.
  connector->Connect(scalarbar, vtkCommand::StartInteractionEvent, this, SLOT(startInteraction()));
  connector->Connect(scalarbar, vtkCommand::EndInteractionEvent, this, SLOT(endInteraction()));
}

//-----------------------------------------------------------------------------
pqScalarBarRepresentation::~pqScalarBarRepresentation() = default;

//-----------------------------------------------------------------------------
#define PUSH_PROPERTY(name)                                                                        \
  {                                                                                                \
    vtkSMPropertyModificationUndoElement* elem = vtkSMPropertyModificationUndoElement::New();      \
    elem->ModifiedProperty(proxy, name);                                                           \
    ADD_UNDO_ELEM(elem);                                                                           \
    elem->Delete();                                                                                \
  }

//-----------------------------------------------------------------------------
void pqScalarBarRepresentation::startInteraction()
{
  BEGIN_UNDO_SET("Move Color Legend");

  vtkSMProxy* proxy = this->getProxy();
  PUSH_PROPERTY("Position");
  PUSH_PROPERTY("ScalarBarLength");
  PUSH_PROPERTY("Orientation");
}

//-----------------------------------------------------------------------------
void pqScalarBarRepresentation::endInteraction()
{
  vtkSMProxy* proxy = this->getProxy();
  PUSH_PROPERTY("Orientation");
  PUSH_PROPERTY("ScalarBarLength");
  PUSH_PROPERTY("Position");
  END_UNDO_SET();
}
